@@ -42,6 +42,10 @@
 #include <ldns/common.h>
 #include <ldns/rdata.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define LDNS_DNAME_NORMALIZE        tolower
 
 /**
@@ -107,6 +111,7 @@ ldns_rdf *ldns_dname_new_frm_str(const char *str);
  * Create a new dname rdf from a string
  * \param[in] s the size of the new dname
  * \param[in] *data pointer to the actual data
+ *
  * \return ldns_rdf*
  */
 ldns_rdf *ldns_dname_new(uint16_t s, void *data);
@@ -115,6 +120,7 @@ ldns_rdf *ldns_dname_new(uint16_t s, void *data);
  * Create a new dname rdf from data (the data is copied)
  * \param[in] size the size of the data
  * \param[in] *data pointer to the actual data
+ *
  * \return ldns_rdf*
  */
 ldns_rdf *ldns_dname_new_frm_data(uint16_t size, const void *data);
@@ -173,6 +179,13 @@ int ldns_dname_interval(const ldns_rdf *prev, const ldns_rdf *middle, const ldns
  */
 bool ldns_dname_str_absolute(const char *dname_str);
 
+/**
+ * Checks whether the given dname is absolute (i.e. ends with a '.')
+ * \param[in] *dname a rdf representing the dname
+ * \return true or false
+ */
+bool ldns_dname_absolute(const ldns_rdf *dname);
+
 /**
  * look inside the rdf and if it is an LDNS_RDF_TYPE_DNAME
  * try and retrieve a specific label. The labels are numbered
@@ -190,4 +203,8 @@ ldns_rdf * ldns_dname_label(const ldns_rdf *rdf, uint8_t labelpos);
  */
 int ldns_dname_is_wildcard(const ldns_rdf* dname);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif	/* LDNS_DNAME_H */
